"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class UpdateFirmwareCheck(google.protobuf.message.Message):
    """
    Check if new firmware available
    Use GET, no payload required
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _Result:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _ResultEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UpdateFirmwareCheck._Result.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UPDATE_AVAILABLE: UpdateFirmwareCheck._Result.ValueType  # 0
        UPDATE_NOT_AVAILABLE: UpdateFirmwareCheck._Result.ValueType  # 1
        UNKNOWN_ERROR: UpdateFirmwareCheck._Result.ValueType  # 255
    class Result(_Result, metaclass=_ResultEnumTypeWrapper):
        pass

    UPDATE_AVAILABLE: UpdateFirmwareCheck.Result.ValueType  # 0
    UPDATE_NOT_AVAILABLE: UpdateFirmwareCheck.Result.ValueType  # 1
    UNKNOWN_ERROR: UpdateFirmwareCheck.Result.ValueType  # 255

    RESULT_FIELD_NUMBER: builtins.int
    NEW_FIRMWARE_VERSION_FIELD_NUMBER: builtins.int
    result: global___UpdateFirmwareCheck.Result.ValueType
    """contains the result of checking the firmware update"""

    new_firmware_version: typing.Text
    """Versionstring of the avaiable firmware"""

    def __init__(self,
        *,
        result: global___UpdateFirmwareCheck.Result.ValueType = ...,
        new_firmware_version: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["new_firmware_version",b"new_firmware_version","result",b"result"]) -> None: ...
global___UpdateFirmwareCheck = UpdateFirmwareCheck

class UpdateFirmwareStart(google.protobuf.message.Message):
    """
    Start firmware update
    Use GET, no payload required
    Important: The response does not tell you anything about the success of the update itself
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _Result:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _ResultEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UpdateFirmwareStart._Result.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UPDATE_STARTED: UpdateFirmwareStart._Result.ValueType  # 0
        UPDATE_NOT_AVAILABLE: UpdateFirmwareStart._Result.ValueType  # 1
        UNKNOWN_ERROR: UpdateFirmwareStart._Result.ValueType  # 255
    class Result(_Result, metaclass=_ResultEnumTypeWrapper):
        pass

    UPDATE_STARTED: UpdateFirmwareStart.Result.ValueType  # 0
    UPDATE_NOT_AVAILABLE: UpdateFirmwareStart.Result.ValueType  # 1
    UNKNOWN_ERROR: UpdateFirmwareStart.Result.ValueType  # 255

    RESULT_FIELD_NUMBER: builtins.int
    result: global___UpdateFirmwareStart.Result.ValueType
    """contains the result of *triggering* the firmware update"""

    def __init__(self,
        *,
        result: global___UpdateFirmwareStart.Result.ValueType = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["result",b"result"]) -> None: ...
global___UpdateFirmwareStart = UpdateFirmwareStart
