"""
@generated by stubgen.  Do not edit manually!
isort:skip_file
"""
from __future__ import annotations
from .getnetworkoverview_pb2 import GetNetworkOverview
from devolo_plc_api.clients import Protobuf
from devolo_plc_api.zeroconf import ZeroconfServiceInfo as ZeroconfServiceInfo
from httpx import AsyncClient as AsyncClient

class PlcNetApi(Protobuf):
    password: str
    def __init__(self, ip: str, session: AsyncClient, info: ZeroconfServiceInfo) -> None: ...
    async def async_get_network_overview(self) -> GetNetworkOverview.LogicalNetwork: ...
    async def async_identify_device_start(self) -> bool: ...
    async def async_identify_device_stop(self) -> bool: ...
    async def async_pair_device(self) -> bool: ...
    async def async_set_user_device_name(self, name: str) -> bool: ...
    def get_network_overview(self) -> GetNetworkOverview.LogicalNetwork: ...
    def identify_device_start(self) -> bool: ...
    def identify_device_stop(self) -> bool: ...
    def pair_device(self) -> bool: ...
    def set_user_device_name(self, name: str) -> bool: ...
