# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pairdevice.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10pairdevice.proto\x12\nplcnet.api\"&\n\x0fPairDeviceStart\x12\x13\n\x0bmac_address\x18\x01 \x01(\t\"\xba\x01\n\x12PairDeviceResponse\x12\x35\n\x06result\x18\x01 \x01(\x0e\x32%.plcnet.api.PairDeviceResponse.Result\"m\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x13\n\x0fMACADDR_INVALID\x10\x01\x12\x13\n\x0fMACADDR_UNKNOWN\x10\x02\x12\x18\n\x13\x43OMMUNICATION_ERROR\x10\xfe\x01\x12\x12\n\rUNKNOWN_ERROR\x10\xff\x01\x42\x11\n\x06plcnetB\x07pairingb\x06proto3')



_PAIRDEVICESTART = DESCRIPTOR.message_types_by_name['PairDeviceStart']
_PAIRDEVICERESPONSE = DESCRIPTOR.message_types_by_name['PairDeviceResponse']
_PAIRDEVICERESPONSE_RESULT = _PAIRDEVICERESPONSE.enum_types_by_name['Result']
PairDeviceStart = _reflection.GeneratedProtocolMessageType('PairDeviceStart', (_message.Message,), {
  'DESCRIPTOR' : _PAIRDEVICESTART,
  '__module__' : 'pairdevice_pb2'
  # @@protoc_insertion_point(class_scope:plcnet.api.PairDeviceStart)
  })
_sym_db.RegisterMessage(PairDeviceStart)

PairDeviceResponse = _reflection.GeneratedProtocolMessageType('PairDeviceResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAIRDEVICERESPONSE,
  '__module__' : 'pairdevice_pb2'
  # @@protoc_insertion_point(class_scope:plcnet.api.PairDeviceResponse)
  })
_sym_db.RegisterMessage(PairDeviceResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\006plcnetB\007pairing'
  _PAIRDEVICESTART._serialized_start=32
  _PAIRDEVICESTART._serialized_end=70
  _PAIRDEVICERESPONSE._serialized_start=73
  _PAIRDEVICERESPONSE._serialized_end=259
  _PAIRDEVICERESPONSE_RESULT._serialized_start=150
  _PAIRDEVICERESPONSE_RESULT._serialized_end=259
# @@protoc_insertion_point(module_scope)
