"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class FactoryResetStart(google.protobuf.message.Message):
    """
    Perform a factory reset on delos devices
    Use GET, no payload required
    The result shows only the success of the triggering
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _Result:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _ResultEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[FactoryResetStart._Result.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SUCCESS: FactoryResetStart._Result.ValueType  # 0
        UNKNOWN_ERROR: FactoryResetStart._Result.ValueType  # 255
    class Result(_Result, metaclass=_ResultEnumTypeWrapper):
        pass

    SUCCESS: FactoryResetStart.Result.ValueType  # 0
    UNKNOWN_ERROR: FactoryResetStart.Result.ValueType  # 255

    RESULT_FIELD_NUMBER: builtins.int
    result: global___FactoryResetStart.Result.ValueType
    """SUCCESS, if factory reset was triggered correct"""

    def __init__(self,
        *,
        result: global___FactoryResetStart.Result.ValueType = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["result",b"result"]) -> None: ...
global___FactoryResetStart = FactoryResetStart
