# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: support.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rsupport.proto\x12\ndevice.api\"\x80\x01\n\x0fSupportInfoDump\x12:\n\x05items\x18\x01 \x03(\x0b\x32+.device.api.SupportInfoDump.SupportInfoItem\x1a\x31\n\x0fSupportInfoItem\x12\r\n\x05label\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"\xb1\x01\n\x17SupportInfoDumpResponse\x12:\n\x06result\x18\x01 \x01(\x0e\x32*.device.api.SupportInfoDumpResponse.Result\x12)\n\x04info\x18\x03 \x01(\x0b\x32\x1b.device.api.SupportInfoDump\")\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x12\n\rUNKNOWN_ERROR\x10\xff\x01J\x04\x08\x02\x10\x03\x42\x11\n\x06\x64\x65viceB\x07supportb\x06proto3')



_SUPPORTINFODUMP = DESCRIPTOR.message_types_by_name['SupportInfoDump']
_SUPPORTINFODUMP_SUPPORTINFOITEM = _SUPPORTINFODUMP.nested_types_by_name['SupportInfoItem']
_SUPPORTINFODUMPRESPONSE = DESCRIPTOR.message_types_by_name['SupportInfoDumpResponse']
_SUPPORTINFODUMPRESPONSE_RESULT = _SUPPORTINFODUMPRESPONSE.enum_types_by_name['Result']
SupportInfoDump = _reflection.GeneratedProtocolMessageType('SupportInfoDump', (_message.Message,), {

  'SupportInfoItem' : _reflection.GeneratedProtocolMessageType('SupportInfoItem', (_message.Message,), {
    'DESCRIPTOR' : _SUPPORTINFODUMP_SUPPORTINFOITEM,
    '__module__' : 'support_pb2'
    # @@protoc_insertion_point(class_scope:device.api.SupportInfoDump.SupportInfoItem)
    })
  ,
  'DESCRIPTOR' : _SUPPORTINFODUMP,
  '__module__' : 'support_pb2'
  # @@protoc_insertion_point(class_scope:device.api.SupportInfoDump)
  })
_sym_db.RegisterMessage(SupportInfoDump)
_sym_db.RegisterMessage(SupportInfoDump.SupportInfoItem)

SupportInfoDumpResponse = _reflection.GeneratedProtocolMessageType('SupportInfoDumpResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUPPORTINFODUMPRESPONSE,
  '__module__' : 'support_pb2'
  # @@protoc_insertion_point(class_scope:device.api.SupportInfoDumpResponse)
  })
_sym_db.RegisterMessage(SupportInfoDumpResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\006deviceB\007support'
  _SUPPORTINFODUMP._serialized_start=30
  _SUPPORTINFODUMP._serialized_end=158
  _SUPPORTINFODUMP_SUPPORTINFOITEM._serialized_start=109
  _SUPPORTINFODUMP_SUPPORTINFOITEM._serialized_end=158
  _SUPPORTINFODUMPRESPONSE._serialized_start=161
  _SUPPORTINFODUMPRESPONSE._serialized_end=338
  _SUPPORTINFODUMPRESPONSE_RESULT._serialized_start=291
  _SUPPORTINFODUMPRESPONSE_RESULT._serialized_end=332
# @@protoc_insertion_point(module_scope)
