# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: identifydevice.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14identifydevice.proto\x12\nplcnet.api\"*\n\x13IdentifyDeviceStart\x12\x13\n\x0bmac_address\x18\x01 \x01(\t\")\n\x12IdentifyDeviceStop\x12\x13\n\x0bmac_address\x18\x01 \x01(\t\"\xc2\x01\n\x16IdentifyDeviceResponse\x12\x39\n\x06result\x18\x01 \x01(\x0e\x32).plcnet.api.IdentifyDeviceResponse.Result\"m\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x13\n\x0fMACADDR_INVALID\x10\x01\x12\x13\n\x0fMACADDR_UNKNOWN\x10\x02\x12\x18\n\x13\x43OMMUNICATION_ERROR\x10\xfe\x01\x12\x12\n\rUNKNOWN_ERROR\x10\xff\x01\x42\x12\n\x06plcnetB\x08identityb\x06proto3')



_IDENTIFYDEVICESTART = DESCRIPTOR.message_types_by_name['IdentifyDeviceStart']
_IDENTIFYDEVICESTOP = DESCRIPTOR.message_types_by_name['IdentifyDeviceStop']
_IDENTIFYDEVICERESPONSE = DESCRIPTOR.message_types_by_name['IdentifyDeviceResponse']
_IDENTIFYDEVICERESPONSE_RESULT = _IDENTIFYDEVICERESPONSE.enum_types_by_name['Result']
IdentifyDeviceStart = _reflection.GeneratedProtocolMessageType('IdentifyDeviceStart', (_message.Message,), {
  'DESCRIPTOR' : _IDENTIFYDEVICESTART,
  '__module__' : 'identifydevice_pb2'
  # @@protoc_insertion_point(class_scope:plcnet.api.IdentifyDeviceStart)
  })
_sym_db.RegisterMessage(IdentifyDeviceStart)

IdentifyDeviceStop = _reflection.GeneratedProtocolMessageType('IdentifyDeviceStop', (_message.Message,), {
  'DESCRIPTOR' : _IDENTIFYDEVICESTOP,
  '__module__' : 'identifydevice_pb2'
  # @@protoc_insertion_point(class_scope:plcnet.api.IdentifyDeviceStop)
  })
_sym_db.RegisterMessage(IdentifyDeviceStop)

IdentifyDeviceResponse = _reflection.GeneratedProtocolMessageType('IdentifyDeviceResponse', (_message.Message,), {
  'DESCRIPTOR' : _IDENTIFYDEVICERESPONSE,
  '__module__' : 'identifydevice_pb2'
  # @@protoc_insertion_point(class_scope:plcnet.api.IdentifyDeviceResponse)
  })
_sym_db.RegisterMessage(IdentifyDeviceResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\006plcnetB\010identity'
  _IDENTIFYDEVICESTART._serialized_start=36
  _IDENTIFYDEVICESTART._serialized_end=78
  _IDENTIFYDEVICESTOP._serialized_start=80
  _IDENTIFYDEVICESTOP._serialized_end=121
  _IDENTIFYDEVICERESPONSE._serialized_start=124
  _IDENTIFYDEVICERESPONSE._serialized_end=318
  _IDENTIFYDEVICERESPONSE_RESULT._serialized_start=209
  _IDENTIFYDEVICERESPONSE_RESULT._serialized_end=318
# @@protoc_insertion_point(module_scope)
