"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RestartResponse(google.protobuf.message.Message):
    """
    Response to calling the "Restart" endpoint to perform a restart of a devolo device.
    The result code shows only the success of the triggering.
    The current uptime of the device is returned so that it can be compared
    to an uptime retrieved at a later time to check for a successful restart.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _Result:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _ResultEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RestartResponse._Result.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SUCCESS: RestartResponse._Result.ValueType  # 0
        """The restart can and will be triggered."""

        UNKNOWN_ERROR: RestartResponse._Result.ValueType  # 255
        """For some unknown error a restart cannot be triggered at this time."""

    class Result(_Result, metaclass=_ResultEnumTypeWrapper):
        pass

    SUCCESS: RestartResponse.Result.ValueType  # 0
    """The restart can and will be triggered."""

    UNKNOWN_ERROR: RestartResponse.Result.ValueType  # 255
    """For some unknown error a restart cannot be triggered at this time."""


    RESULT_FIELD_NUMBER: builtins.int
    UPTIME_FIELD_NUMBER: builtins.int
    result: global___RestartResponse.Result.ValueType
    """SUCCESS, if restart can and will be triggered"""

    uptime: builtins.int
    """Current uptime of the device. No unit is attached to the value."""

    def __init__(self,
        *,
        result: global___RestartResponse.Result.ValueType = ...,
        uptime: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["result",b"result","uptime",b"uptime"]) -> None: ...
global___RestartResponse = RestartResponse

class UptimeGetResponse(google.protobuf.message.Message):
    """
    Response to calling the "UptimeGet" endpoint.
    The current uptime of the device is returned.
    No unit (like seconds or millisenconds or ticks) is attached to the value.
    You can only use the uptime value as a strict monotonically increasing number,
    that increases in regular intervals since the device started.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UPTIME_FIELD_NUMBER: builtins.int
    uptime: builtins.int
    """Current uptime of the device. No unit is attached to the value."""

    def __init__(self,
        *,
        uptime: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["uptime",b"uptime"]) -> None: ...
global___UptimeGetResponse = UptimeGetResponse
