# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ledsettings.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11ledsettings.proto\x12\ndevice.api\"i\n\x0eLedSettingsGet\x12\x32\n\x05state\x18\x01 \x01(\x0e\x32#.device.api.LedSettingsGet.Ledstate\"#\n\x08Ledstate\x12\n\n\x06LED_ON\x10\x00\x12\x0b\n\x07LED_OFF\x10\x01\"i\n\x0eLedSettingsSet\x12\x32\n\x05state\x18\x01 \x01(\x0e\x32#.device.api.LedSettingsSet.Ledstate\"#\n\x08Ledstate\x12\n\n\x06LED_ON\x10\x00\x12\x0b\n\x07LED_OFF\x10\x01\"~\n\x16LedSettingsSetResponse\x12\x39\n\x06result\x18\x01 \x01(\x0e\x32).device.api.LedSettingsSetResponse.Result\")\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x12\n\rUNKNOWN_ERROR\x10\xff\x01\x42\x0e\n\x06\x64\x65viceB\x04ledsb\x06proto3')



_LEDSETTINGSGET = DESCRIPTOR.message_types_by_name['LedSettingsGet']
_LEDSETTINGSSET = DESCRIPTOR.message_types_by_name['LedSettingsSet']
_LEDSETTINGSSETRESPONSE = DESCRIPTOR.message_types_by_name['LedSettingsSetResponse']
_LEDSETTINGSGET_LEDSTATE = _LEDSETTINGSGET.enum_types_by_name['Ledstate']
_LEDSETTINGSSET_LEDSTATE = _LEDSETTINGSSET.enum_types_by_name['Ledstate']
_LEDSETTINGSSETRESPONSE_RESULT = _LEDSETTINGSSETRESPONSE.enum_types_by_name['Result']
LedSettingsGet = _reflection.GeneratedProtocolMessageType('LedSettingsGet', (_message.Message,), {
  'DESCRIPTOR' : _LEDSETTINGSGET,
  '__module__' : 'ledsettings_pb2'
  # @@protoc_insertion_point(class_scope:device.api.LedSettingsGet)
  })
_sym_db.RegisterMessage(LedSettingsGet)

LedSettingsSet = _reflection.GeneratedProtocolMessageType('LedSettingsSet', (_message.Message,), {
  'DESCRIPTOR' : _LEDSETTINGSSET,
  '__module__' : 'ledsettings_pb2'
  # @@protoc_insertion_point(class_scope:device.api.LedSettingsSet)
  })
_sym_db.RegisterMessage(LedSettingsSet)

LedSettingsSetResponse = _reflection.GeneratedProtocolMessageType('LedSettingsSetResponse', (_message.Message,), {
  'DESCRIPTOR' : _LEDSETTINGSSETRESPONSE,
  '__module__' : 'ledsettings_pb2'
  # @@protoc_insertion_point(class_scope:device.api.LedSettingsSetResponse)
  })
_sym_db.RegisterMessage(LedSettingsSetResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\006deviceB\004leds'
  _LEDSETTINGSGET._serialized_start=33
  _LEDSETTINGSGET._serialized_end=138
  _LEDSETTINGSGET_LEDSTATE._serialized_start=103
  _LEDSETTINGSGET_LEDSTATE._serialized_end=138
  _LEDSETTINGSSET._serialized_start=140
  _LEDSETTINGSSET._serialized_end=245
  _LEDSETTINGSSET_LEDSTATE._serialized_start=103
  _LEDSETTINGSSET_LEDSTATE._serialized_end=138
  _LEDSETTINGSSETRESPONSE._serialized_start=247
  _LEDSETTINGSSETRESPONSE._serialized_end=373
  _LEDSETTINGSSETRESPONSE_RESULT._serialized_start=332
  _LEDSETTINGSSETRESPONSE_RESULT._serialized_end=373
# @@protoc_insertion_point(module_scope)
