# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: factoryreset.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x66\x61\x63toryreset.proto\x12\ndevice.api\"t\n\x11\x46\x61\x63toryResetStart\x12\x34\n\x06result\x18\x01 \x01(\x0e\x32$.device.api.FactoryResetStart.Result\")\n\x06Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x12\n\rUNKNOWN_ERROR\x10\xff\x01\x42\x16\n\x06\x64\x65viceB\x0c\x66\x61\x63toryresetb\x06proto3')



_FACTORYRESETSTART = DESCRIPTOR.message_types_by_name['FactoryResetStart']
_FACTORYRESETSTART_RESULT = _FACTORYRESETSTART.enum_types_by_name['Result']
FactoryResetStart = _reflection.GeneratedProtocolMessageType('FactoryResetStart', (_message.Message,), {
  'DESCRIPTOR' : _FACTORYRESETSTART,
  '__module__' : 'factoryreset_pb2'
  # @@protoc_insertion_point(class_scope:device.api.FactoryResetStart)
  })
_sym_db.RegisterMessage(FactoryResetStart)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\006deviceB\014factoryreset'
  _FACTORYRESETSTART._serialized_start=34
  _FACTORYRESETSTART._serialized_end=150
  _FACTORYRESETSTART_RESULT._serialized_start=109
  _FACTORYRESETSTART_RESULT._serialized_end=150
# @@protoc_insertion_point(module_scope)
