# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: multiap.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rmultiap.proto\x12\ndevice.api\"W\n\x16WifiMultiApGetResponse\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x15\n\rcontroller_id\x18\x02 \x01(\t\x12\x15\n\rcontroller_ip\x18\x03 \x01(\tB\x11\n\x06\x64\x65viceB\x07Multiapb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'multiap_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\006deviceB\007Multiap'
  _WIFIMULTIAPGETRESPONSE._serialized_start=29
  _WIFIMULTIAPGETRESPONSE._serialized_end=116
# @@protoc_insertion_point(module_scope)
